VehicleIdentificationResponse

Struct VehicleIdentificationResponse 

pub struct VehicleIdentificationResponse {
    pub vin: Vin,
    pub logical_address: LogicalAddress,
    pub eid: Eid,
    pub gid: Option<Gid>,
    pub further_action: FurtherActionRequired,
    pub vin_gid_sync_status: VinGidSyncStatus,
}
Vehicle identiifcation response / Vehicle announcement

This is the response to VehicleIdentificationRequest, sent by a DoIP entity to a DoIP external tester.

Fields

vin: Vin

Vehicle Identification Number.

logical_address: LogicalAddress

Logical address of the DoIP entity.

eid: Eid

Unique entitiy identification (EID), e.g. MAC address of network interface.

gid: Option<Gid>

None when value not set (as indicated by 0x00 or 0xFF).

further_action: FurtherActionRequired

Further action to be taken by the external tester.

vin_gid_sync_status: VinGidSyncStatus

Indicates whether all entites have synced information about VIN or GID.